==> lcsm_0.1.2.tar.gz: lcsm/R/data.R <==
#' Longitudinal dataset with repeated measures of one constructs
#'
#' @description Example dataset with repeated measures of one constructs to illustrate how the package works.
#' @docType data
#' @usage data(data_uni_lcsm)
#' @format A longitudinal dataset in wide format:
#' \itemize{
#'   \item{id}{: ID variable, unique identifier for each person}
#'   \item{x1}{: x value at time point 1}
#'   \item{x2}{: x value at time point 2}
#'   \item{x3}{: x value at time point 3}
#'   \item{x4}{: x value at time point 4}
#'   \item{x5}{: x value at time point 5}
#'   \item{x6}{: x value at time point 6}
#'   \item{x7}{: x value at time point 7}
#'   \item{x8}{: x value at time point 8}
#'   \item{x9}{: x value at time point 9}
#'   \item{x10}{: x value at time point 10}
#' }
#' @keywords dataset
#' @examples
#' # Load data into global environment
#' data(data_uni_lcsm)
"data_uni_lcsm"

#' Longitudinal dataset with repeated measures of two constructs
#'
#' @description Example dataset with repeated measures of two constructs to illustrate how the package works.
#' @docType data
#' @usage data(data_bi_lcsm)
#' @format A longitudinal dataset in wide format:
#' \itemize{
#'   \item{id}{: ID variable, unique identifier for each person}
#'   \item{x1}{: x value at time point 1}
#'   \item{x2}{: x value at time point 2}
#'   \item{x3}{: x value at time point 3}
#'   \item{x4}{: x value at time point 4}
#'   \item{x5}{: x value at time point 5}
#'   \item{x6}{: x value at time point 6}
#'   \item{x7}{: x value at time point 7}
#'   \item{x8}{: x value at time point 8}
#'   \item{x9}{: x value at time point 9}
#'   \item{x10}{: x value at time point 10}
#'   \item{y1}{: y value at time point 1}
#'   \item{y2}{: y value at time point 2}
#'   \item{y3}{: y value at time point 3}
#'   \item{y4}{: y value at time point 4}
#'   \item{y5}{: y value at time point 5}
#'   \item{y6}{: y value at time point 6}
#'   \item{y7}{: y value at time point 7}
#'   \item{y8}{: y value at time point 8}
#'   \item{y9}{: y value at time point 9}
#'   \item{y10}{: y value at time point 10}
#' }
#' @keywords dataset
#' @examples
#' # Load data into global environment
#' data(data_bi_lcsm)
"data_bi_lcsm"

==> lcsm_0.3.1.tar.gz: lcsm/R/data.R <==
#' Longitudinal dataset with repeated measures of one constructs
#'
#' @description Example dataset with repeated measures of one constructs to illustrate how the package works.
#' @docType data
#' @usage data(data_uni_lcsm)
#' @format A longitudinal dataset in wide format:
#' \itemize{
#'   \item{id}{: ID variable, unique identifier for each person}
#'   \item{x1}{: x value at time point 1}
#'   \item{x2}{: x value at time point 2}
#'   \item{x3}{: x value at time point 3}
#'   \item{x4}{: x value at time point 4}
#'   \item{x5}{: x value at time point 5}
#'   \item{x6}{: x value at time point 6}
#'   \item{x7}{: x value at time point 7}
#'   \item{x8}{: x value at time point 8}
#'   \item{x9}{: x value at time point 9}
#'   \item{x10}{: x value at time point 10}
#' }
#' @keywords dataset
#' @examples
#' # Load data into global environment
#' data(data_uni_lcsm)
"data_uni_lcsm"

#' Longitudinal dataset with repeated measures of two constructs
#'
#' @description Example dataset with repeated measures of two constructs to illustrate how the package works.
#' @docType data
#' @usage data(data_bi_lcsm)
#' @format A longitudinal dataset in wide format:
#' \itemize{
#'   \item{id}{: ID variable, unique identifier for each person}
#'   \item{x1}{: x value at time point 1}
#'   \item{x2}{: x value at time point 2}
#'   \item{x3}{: x value at time point 3}
#'   \item{x4}{: x value at time point 4}
#'   \item{x5}{: x value at time point 5}
#'   \item{x6}{: x value at time point 6}
#'   \item{x7}{: x value at time point 7}
#'   \item{x8}{: x value at time point 8}
#'   \item{x9}{: x value at time point 9}
#'   \item{x10}{: x value at time point 10}
#'   \item{y1}{: y value at time point 1}
#'   \item{y2}{: y value at time point 2}
#'   \item{y3}{: y value at time point 3}
#'   \item{y4}{: y value at time point 4}
#'   \item{y5}{: y value at time point 5}
#'   \item{y6}{: y value at time point 6}
#'   \item{y7}{: y value at time point 7}
#'   \item{y8}{: y value at time point 8}
#'   \item{y9}{: y value at time point 9}
#'   \item{y10}{: y value at time point 10}
#' }
#' @keywords dataset
#' @examples
#' # Load data into global environment
#' data(data_bi_lcsm)
"data_bi_lcsm"


#' Longitudinal dataset with repeated measures of two constructs
#'
#' @description Example dataset with 5 repeated measures of two constructs to illustrate how the package works.
#' @docType data
#' @usage data(lcsm_data)
#' @format A longitudinal dataset in wide format:
#' \itemize{
#'   \item{id}{: ID variable, unique identifier for each person}
#'   \item{x1}{: x value at time point 1}
#'   \item{x2}{: x value at time point 2}
#'   \item{x3}{: x value at time point 3}
#'   \item{x4}{: x value at time point 4}
#'   \item{x5}{: x value at time point 5}
#'   \item{y1}{: y value at time point 1}
#'   \item{y2}{: y value at time point 2}
#'   \item{y3}{: y value at time point 3}
#'   \item{y4}{: y value at time point 4}
#'   \item{y5}{: y value at time point 5}
#' }
#' @keywords dataset
#' @examples
#' # Load data into global environment
#' data(lcsm_data)
"lcsm_data"
